@@ -22,6 +22,15 @@ REPORT_DESCRIPTION_TEMPLATE = """
 
 ${description}
 """
+CLOSE_LOG_TEMPLATE = """
+**Report closed**:
+
+${old_status} -> ${new_status}
+
+**Comment**:
+
+${comment}
+"""
 COMMENT_BODY_TEMPLATE = """
 **Date**: ${date}
 
@@ -84,6 +93,7 @@ class ReportMessageMarkdownFormatter(ReportMessageFormatter):
         super().__init__(
             report_title_template=Template(REPORT_TITLE_TEMPLATE),
             report_description_template=Template(REPORT_DESCRIPTION_TEMPLATE),
+            close_log_template=Template(CLOSE_LOG_TEMPLATE),
             comment_body_template=Template(COMMENT_BODY_TEMPLATE),
             comment_log_template=Template(COMMENT_LOG_TEMPLATE),
             cvss_update_log_template=Template(CVSS_UPDATE_LOG_TEMPLATE),
